@@ -1,6 +1,6 @@
 package SHARYANTO::Proc::Daemon::Prefork;
 BEGIN {
-  $SHARYANTO::Proc::Daemon::Prefork::VERSION = '0.04';
+  $SHARYANTO::Proc::Daemon::Prefork::VERSION = '0.05';
 }
 
 use 5.010;
@@ -13,7 +13,7 @@ use IO::Select;
 use POSIX;
 use Symbol;
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 # --- globals
 
@@ -87,16 +87,17 @@ sub kill_running {
 sub open_logs {
     my ($self) = @_;
 
-    $self->{error_log_path} or die "BUG: Please specify error_log_path";
-    open my($fhe), ">>", $self->{error_log_path}
-        or die "Cannot open error log file $self->{error_log_path}: $!\n";
-    $self->{_error_log} = $fhe;
-
-    $self->{access_log_path} or die "BUG: Please specify access_log_path";
-    open my($fha), ">>", $self->{access_log_path}
-        or die "Cannot open access log file $self->{access_log_path}: $!\n";
-    $self->{_access_log} = $fha;
+    if ($self->{error_log_path}) {
+        open my($fhe), ">>", $self->{error_log_path}
+            or die "Cannot open error log file $self->{error_log_path}: $!\n";
+        $self->{_error_log} = $fhe;
+    }
 
+    if ($self->{access_log_path}) {
+        open my($fha), ">>", $self->{access_log_path}
+            or die "Cannot open access log file $self->{access_log_path}: $!\n";
+        $self->{_access_log} = $fha;
+    }
 }
 
 sub close_logs {
@@ -581,7 +582,7 @@ SHARYANTO::Proc::Daemon::Prefork - Create preforking, autoreloading daemon
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =for Pod::Coverage .
 
